HiC_HMRF_Bayes <-
function(U, E, burnIn = 5000, iter = 5000, verbose=1) {
# E=x$ExpectedCountMatrix
# U=x$ObservedCountMatrix
tE=t(E); tU=t(U)
E[is.na(E)]=tE[is.na(E)]
U[is.na(U)]=tU[is.na(U)]

if ( sum(is.na(E[upper.tri(E)]))>0 )
{ print("There are NAs in the expected count matrix. Check the data to make sure it covers all pairs of fragments. Example: 10 pair of loci should have 10*9/2=45 interactions."); return(NULL)}
if ( sum(is.na(U[upper.tri(U)]))>0 )
{ print("There are NAs in the expected count matrix. Check the data to make sure it covers all pairs of fragments. Example: 10 pair of loci should have 10*9/2=45 interactions."); return(NULL)}
if ( sum(E[upper.tri(E)]<=0) >0 )
{ print("Expected count should not be zero or negative. Please make sure the expected information has already been included for all pair of fragment pairs."); return(NULL)}

# array(1:9,dim=c(3,3))
# array(1:9,dim=c(3,3))
# hmrf(array(1:100,dim=c(10,10)),array(100:1,dim=c(10,10))       )
# Not deleting fragment with marginal count 0.

  # Parameters
  iter = iter + burnIn # total iteration
  theta.alpha <- 2
  theta.beta <- 1
  theta.min <- 0.4
  phi.alpha <- 20
  phi.beta <- 1

  # Initialize theta, phi and x_ij

  theta <- 0.7
  phi <- 20
  psi <- 0.5
  ratio <- U / E
  X <- ratio
  X[ratio > 2] <- 1
  X[(E == 0) | (ratio <= 2)] <- -1
  X[lower.tri(X)] <- NA
  diag(X) <- NA
  # rownames(X) <- frag
  # colnames(X) <- frag
  X.accum <- X
  X.accum[!is.na(X.accum)] <- 0

  theta.path <- theta
  phi.path <- phi
  psi.path <- psi

  logConditionTheta <- function(x) {
    f <- (theta.alpha - 1) * log(x - theta.min) - theta.beta * (x - theta.min)
    mat.grid <- expand.grid(1:nrow(U), 1:ncol(U))
    tri.grid <- mat.grid[mat.grid$Var1 < mat.grid$Var2,]
    coord <- (tri.grid$Var2 - 1) * nrow(U) + tri.grid$Var1
    coord <- coord[!is.na(X[coord])]
    f <- f + sum(- (phi + U[coord]) * log(phi + E[coord] * exp(x * (X[coord] + 1) / 2)) + U[coord] * x * (X[coord] + 1) / 2)
    return(f)
  }

  logConditionPhi <- function(x) {
    f <- (phi.alpha - 1) * log(x) - phi.beta * x
    mat.grid <- expand.grid(1:nrow(U), 1:ncol(U))
    tri.grid <- mat.grid[mat.grid$Var1 < mat.grid$Var2,]
    coord <- (tri.grid$Var2 - 1) * nrow(U) + tri.grid$Var1
    coord <- coord[!is.na(X[coord])]
    f <- f + sum(x * log(x) - (x + U[coord]) * log(x + E[coord] * exp(theta * (X[coord] + 1) / 2)) + lgamma(x + U[coord]) - lgamma(x))
    return(f)
  }

  logConditionPsi <- function(x) {
    
    na.transform <- function(y) {
      z <- y
      z[is.na(y)] <- -1
      return(z)
    }

    f <- 0
    mat.grid <- expand.grid(2:nrow(X), 1:(ncol(X) - 1))
    tri.grid <- mat.grid[(mat.grid$Var1 + 1) < mat.grid$Var2,]
    coord <- (tri.grid$Var2 - 1) * nrow(X) + tri.grid$Var1

    neighbor <- na.transform(X[coord - 1]) + na.transform(X[coord + 1]) + na.transform(X[coord - nrow(X)]) + na.transform(X[coord + nrow(X)])
    f <- f + sum(x * na.transform(X[coord]) * neighbor - log(exp(x * neighbor) + exp(- x * neighbor)))
    return(f)
  }

  logConditionXij <- function(x) {

    f <- - (phi + U[i, j]) * log(phi + E[i, j] * exp(theta * (x + 1) / 2)) + U[i, j] * theta * (x + 1) / 2
    if ((i > 1) & (i - 1 < j)) {
      if (!is.na(X[i - 1, j])) {
        f = f + psi * x * X[i - 1, j]
      }
    }
    if ((i < nrow(U)) & (i + 1 < j)) {
      if (!is.na(X[i + 1, j])) {
        f = f + psi * x * X[i + 1, j]
      }
    }
    if ((j > 1) & (i < j - 1)) {
      if (!is.na(X[i, j - 1])) {
        f = f + psi * x * X[i, j - 1]
      }
    }
    if ((j < ncol(U)) & (i < j + 1)) {
      if (!is.na(X[i, j + 1])) {
        f = f + psi * x * X[i, j + 1]
      }
    }
    return(f)
  }


print(paste("Totally ",iter," simulations."))
set.seed(1) # random seed set as 1
for (iter.id in 1:iter) {

if (verbose==1){
    if (iter.id %% 200 == 0) {
      print(paste("Iteration ", iter.id, "...", sep = ""))
      print(paste("Theta=", theta, ", Phi=", phi, ", Psi=", psi, sep = ""))
    }
}

    # Update theta

    theta.propose <- theta + rnorm(1, sd = 0.01)
    while (theta.propose <= theta.min) {
      theta.propose <- theta + rnorm(1, sd = 0.01)
    }
    logConTheta <- logConditionTheta(theta)
    logConTheta.propose <- logConditionTheta(theta.propose)
    alpha <- dgamma(theta - theta.min, theta.alpha, theta.beta) / dgamma(theta.propose - theta.min, theta.alpha, theta.beta) * exp(logConTheta.propose - logConTheta)
    if (!is.finite(alpha)) {
      alpha <- 0
    }
    if (runif(1) <= alpha) {
      theta <- theta.propose
    }
    theta.path <- c(theta.path, theta)

    # Update phi

    phi.propose <- 1 / (1 / phi + rnorm(1, sd = 0.01))
    while (phi.propose <= 0) {
      phi.propose <- 1 / (1 / phi + rnorm(1, sd = 0.01))
    }
    logConPhi <- logConditionPhi(phi)
    logConPhi.propose <- logConditionPhi(phi.propose)
    alpha <- dgamma(phi, phi.alpha, phi.beta) / dgamma(phi.propose, phi.alpha, phi.beta) * exp(logConPhi.propose - logConPhi)
    if (!is.finite(alpha)) {
      alpha <- 0
    }
    if (runif(1) <= alpha) {
      phi <- phi.propose
    }
    phi.path <- c(phi.path, phi)

    # Update psi

    psi.propose <- psi + rnorm(1, sd = 0.01)
    while ((psi.propose < 0) | (psi.propose > 1)) {
      psi.propose <- psi + rnorm(1, sd = 0.01)
    }
    logConPsi <- logConditionPsi(psi)
    logConPsi.propose <- logConditionPsi(psi.propose)
    alpha <- exp(logConPsi.propose - logConPsi)
    if (runif(1) <= alpha) {
      psi <- psi.propose
    }
    psi.path <- c(psi.path, psi)

    # Update x_ij

    for (i in 1:(nrow(U) - 1)) {
      for (j in (i + 1):ncol(U)) {
        logConXij <- logConditionXij(X[i, j])
        logConXij.propose <- logConditionXij(-X[i, j])
        alpha <- exp(logConXij.propose - logConXij)
        X[i, j] <- (-1) ^ (runif(1) <= alpha) * X[i, j]
      }
    }

    if (iter.id > burnIn) {
      X.accum <- X.accum + (X + 1) / 2
    }

  }

  # plot(theta.path)
  # plot(phi.path)
  X.accum <- X.accum / (iter - burnIn)

  mat.grid <- expand.grid(1:nrow(U), 1:ncol(U))
  tri.grid <- mat.grid[mat.grid$Var1 < mat.grid$Var2,]
  coord <- (tri.grid$Var2 - 1) * nrow(U) + tri.grid$Var1    
  X.accum[coord[E[coord] < 1e-5]]
  
  theta.density <- density(theta.path[(burnIn + 1):iter])
  theta.estimate <- theta.density$x[theta.density$y == max(theta.density$y)]
  phi.density <- density(phi.path[(burnIn + 1):iter])
  phi.estimate <- phi.density$x[phi.density$y == max(phi.density$y)]
  psi.density <- density(psi.path[(burnIn + 1):iter])
  psi.estimate <- psi.density$x[psi.density$y == max(psi.density$y)]
cat("\n")
  return(list(posterior.probability=X.accum, expected.count=E, observed.count=U, theta.estimate=theta.estimate, phi.estimate=phi.estimate, psi.estimate=psi.estimate))
}
