\name{HMRFBayesHiC-package}
\alias{HMRFBayesHiC-package}
\alias{HMRFBayesHiC}
\docType{package}
\title{
Hidden Markov Random Field Bayesian Hi-C Peak Calling 
}
\description{
HMRFBayesHiC helps researchers to conduct peak calling of Hi-C data by our Hidden Markov Random Field-Bayesian method. The input data is a text file, with 4 columns respectively as fragment 1, fragment 2, observed frequency and expected frequency. The output peak probability result is a a text file, with 5 columns respectively as fragment 1, fragment 2, observed frequency, expected frequency and peak probability.
HMRFBayesHiC include two ways for the user to conduct peak calling. One way is the pipeline calling via the function \code{HiC_HMRF_Bayes}. The user just need to specify input data file and output result file and \code{HiC_HMRF_Bayes} will conduct all things.
The other way is the three-step running, using \code{HiC_Prepare_Matrix}, \code{HiC_HMRF_Bayes} and \code{HiC_Output} respectively for data loading, peak calling and result outputting steps. The demonstration code is listed below and the toy data include Hi-C information for Fragment 15060-15069 as the file "toyHiC_frag15060_15069.txt". 
}
\details{
\tabular{ll}{
Package: \tab HMRFBayesHiC\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2015-01-30\cr
License: \tab GPL-3\cr
}
The pipeline function \code{HiC_HMRF_Bayes} conducts our HMRF-Bayes peak calling from inut file to output file, in three steps: (1) data loading using \code{HiC_Prepare_Matrix}, (2) peak calling using \code{HiC_HMRF_Bayes} and (3) results outputting using \code{HiC_Output}.

}
\author{
Zheng Xu

Maintainer: Zheng Xu <xuzheng@email.unc.edu>
}
\references{
Xu et al, A hidden Markov random field based Bayesian method for the detection of long-range chromosomal interactions in Hi-C Data, Manuscript.
}

\keyword{ package }
\keyword{ HMRFBayesHiC-package }

\examples{
## An example of loading data, run peak caller and output results. 
## Our toy example of HiC data is for fragment 15060-15069 of IMR90 12 cell data.

##  Conduct Hi-C HMRF in three steps.
## (1) loading data, (2) peak calling and (3) outputting results.
 HiC.Data=HiC_Prepare_Matrix(file="toyHiC_frag15060_15069.txt",
     verbose=TRUE,sep="\t",header=TRUE)
 HiC.Results=HiC_HMRF_Bayes(HiC.Data$ObservedCountMatrix, 
     HiC.Data$ExpectedCountMatrix, burnIn = 5000, iter = 5000, verbose=1)
 HiC_Output(HiCResults=HiC.Results,fragIDs=HiC.Data$fragIDs,
     probfile="toyHiC_frag15060_15069_Results.txt",
     estimatorfile="toyHiC_frag15060_15069_Estimated_Parameters.txt")

## Conduct Hi-C HMRF in one function for all.
 HiC_HMRF_Bayes_File(file="toyHiC_frag15060_15069.txt",
     probfile="toyHiC_frag15060_15069_Results.txt", 
	  estimatorfile="toyHiC_frag15060_15069_Estimated_Parameters.txt",
     sep="\t",header=TRUE, verbose=TRUE, burnIn = 5000, iter = 5000)
	 
## Plot heatmap of observed frequency, expected frequency and peak probability

## Plot the heatmap of observed frequency 
## which is at column 3 of the HiC data file.
HiC_Plot_Heatmap(file="toyHiC_frag15060_15069.txt",index=c(1,2,3),
      verbose=TRUE,sep="\t",header=TRUE,negative.log10.scale=FALSE,
	  xlab="Fragment Index",ylab="Fragment Index",main="Observed Frequency")

## Plot the heatmap of expected frequency 
## which is at column 4 of the HiC data file.
HiC_Plot_Heatmap(file="toyHiC_frag15060_15069.txt",index=c(1,2,4),
      verbose=TRUE,sep="\t",header=TRUE,negative.log10.scale=FALSE,
	  xlab="Fragment Index",ylab="Fragment Index",main="Expected Frequency")

## Plot the heatmap of posterior probability 
## which is at column 5 of the HiC result file.
HiC_Plot_Heatmap(file="toyHiC_frag15060_15069_Results.txt",index=c(1,2,5),
      verbose=TRUE,sep="\t",header=TRUE,negative.log10.scale=FALSE,
	  xlab="Fragment Index",ylab="Fragment Index",main="Posterior Probability")	 
}
