\name{HiC_Output}
\alias{HiC_Output}

\title{
 HiC HMRF Bayes Method Result Output
}
\description{
The function of outputting HiC HMRF Bayes peak caller results to files. It outputs estimated peak probability file into probfile and outputs estimated parameters of theta, phi and psi into estimator file.
}
\usage{
HiC_Output(HiCResults, fragIDs, probfile, estimatorfile)
}

\arguments{
  \item{HiCResults}{
	the results of HiC-HMRF-Bayes peak caller, which can take the output of the function \code{HiC_HMRF_Bayes}.
}
  \item{fragIDs}{
	the names of fragments in an increasing order, which can take the output from the function \code{HiC_Prepare_Matrix}. 
}
  \item{probfile}{
    the file to output the estimated peak probability matrix by HiC HMRF Bayes method, either a character string naming a file or a connection open for writing. 
}
  \item{estimatorfile}{
	the file to output the estimated parameters of theta, phi and psi by HiC HMRF Bayes method, either a character string naming a file or a connection open for writing.
}
}
\details{
 The function of outputting Hi-C HMRF Bayes peak caller results to files. It outputs estimated peak probability file into probfile and outputs estimated parameters of theta, phi and psi into estimator file.
}
\value{
It does not return any value. The function will write estimated peak probability in the prob file and estimated parameters in estimator file. The prob file is a text file with 5 columns respectively as fragment 1, fragment 2, observed frequencies, expected frequencies and peak probabilities.
}
\references{
Xu et al, A hidden Markov random field based Bayesian method for the detection of long-range chromosomal interactions in HiC Data, Manuscript.
}
\author{
Zheng Xu
}

\examples{
## An example of loading data, run peak caller and output results. 
## Our toy example of HiC data for fragment 15060-15069.
#
 HiC.Data=HiC_Prepare_Matrix(file="toyHiC_frag15060_15069.txt",
       verbose=TRUE,sep="\t",header=TRUE)
 HiC.Results=HiC_HMRF_Bayes(HiC.Data$ObservedCountMatrix, 
       HiC.Data$ExpectedCountMatrix, burnIn = 5000, iter = 5000, verbose=1)
 HiC_Output(HiCResults=HiC.Results,fragIDs=HiC.Data$fragIDs,
       probfile="toyHiC_frag15060_15069_Results.txt",
       estimatorfile="toyHiC_frag15060_15069_Estimated_Parameters.txt")
}

\keyword{ HiC_Output }
