\name{HiC_Prepare_Matrix}
\alias{HiC_Prepare_Matrix}
\title{
HiC HMRF Bayes Method Data Input
}
\description{
\code{HiC_Prepare_Matrix} load data into the memory and prepare the matrix of expected count and observed count for further analysis. 
}
\usage{
HiC_Prepare_Matrix(file, verbose = TRUE, sep = "\t", header = TRUE)
}

\arguments{
  \item{file}{
 the file to be loaded, which is a text file, with four columns respectively as fragment 1, fragment 2, observed frequency and expected frequency. 
}
  \item{verbose}{
 a logical value, controling whether the function be verbose in loading the data, reporting the number of observations loaded or be silent (not report).
}
  \item{sep}{
  the field separator character. Values on each line of the file are separated by this character. 
}
  \item{header}{
 a logical value indicating whether the file contains the names of the variables as its first line. If missing, the value is determined from the file format: header is set to TRUE if and only if the first row contains one fewer field than the number of columns.
}
}
\details{
\code{HiC_Prepare_Matrix} load data into the memory and prepare the matrix of expected count and observed count for further analysis. If the file specified does not exist, it will output "File not exist". If success, it will return the loaded data. If fails, it will return NULL. Please use \code{is.null()} to check whether the function runs successfully.
}
\value{
 A list including three items.
  \item{ExpectedCountMatrix}{The matrix of expected frequencies.}
  \item{ObservedCountMatrix}{The matrix of observed frequencies.}
  \item{fragIDs}{The fragment names in an increasing order.}
}
\references{
Xu et al, A hidden Markov random field based Bayesian method for the detection of long-range chromosomal interactions in Hi-C Data, Manuscript
}
\author{
  Zheng Xu
}

\examples{
## For our toy example of HiC data for fragment 15060-15069.
   HiC.Data=HiC_Prepare_Matrix(file="toyHiC_frag15060_15069.txt",
      verbose=TRUE,sep="\t",header=TRUE)
}

\keyword{ HiC_Prepare_Matrix }
